yt.utilities.lib.distance\_queue module
=======================================

.. automodule:: yt.utilities.lib.distance_queue
   :members:
   :undoc-members:
   :inherited-members:
   :show-inheritance:
